#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Cleans raw data file by removing duplicated file headers, adding data numbers
to each row, and averaging results of repeated runs.

@author: Aidan Combs
@version: 1.0
"""

import pandas as pd
import numpy as np


def get_dn(number):
    result = []
    # change values based on cutoff row numbers in input csv file
    for el in number:
        el = float(el)
        if el <= 47:
            result.append(3)
        elif el <= 95:
            result.append(4)
        else:
            result.append(5)
    return result

c = ['number', 'fraction_in', 'test_cen', 'train_cen', 'out_num',
     'all_test_num', 'degree', 'inputs', 'terms', 'blocksize',
     'val_type', 'model_type', 'cropped_pixels', 'eval_time_per_pixel',
     'eval_time_sd', 'average_fit_time_total',
     'rms_pct', 'rms_pct_sem', 'rms', 'rms_sem', 'pct_imp',
     '1-r^2', 'amorph_rms', 'mixed_rms', 'xtal_rms',
     'amorph_1-r^2', 'mixed_1-r^2', 'xtal_1-r^2']

# change file name to desired results file
r = pd.read_csv('PtPtMoPtMo50_run1_cv6_all.csv', names=c)
r = r.drop_duplicates(keep=False)
r = r.astype(float)
dn_vals = get_dn(r.number)
r = r.assign(datanum=dn_vals)
c.append('datanum')
orig_length = r.shape[0]
to_delete = []
r_add = pd.DataFrame(columns=c)

numbers = np.array(r['number'])
for i in range(orig_length):
    num = numbers[i]
    for j in range(i+1, orig_length):
        if num == numbers[j]:
            newrow = pd.DataFrame(np.zeros([1, len(c)]), columns=c)
            for k in range(len(c)):
                label = c[k]
                newrow.loc[0, label] = (r.iloc[i, k] + r.iloc[j, k])/2
            r_add = r_add.append(newrow)
            to_delete.append(num)
            # average two matching rows and put in a new row.
            # append the new row to the bottom of the array.
            # record number of matching rows in to_delete.

r = r.reset_index(drop=True)
for i in range(orig_length-1, -1, -1):
    if r.loc[i, 'number'] in to_delete:
        r = r.drop([i], axis=0)

r = r.append(r_add)

# write cleaned file to csv
r.to_csv('PtPtMoPtMo50_run1_cv6_cleaned.csv', index=False)
